function [imSegmented imContour] = segmentimage2(imOriginal, tresh, blkSize, enh, smooth)

%[imSegmented imContour] = segmentimage(imOriginal, blkSize, enh, smooth)
%
% Funkce segmentuje obrazek na otisk a pozadi. Vypocet probiha po blocich.
%
%   imOriginal - vstupni otisk
%   tresh - prah pro segmentaci otisku
%   blkSize - velikost bloku pro rozmazani gradientniho obrazu
%   enh - vylepseni kontrastu, TRUE pro zapnuto, FALSE pro vypnuto
%   smooth - velikost vyhlazovaciho okna pro vyhlazeni konecne kontury
%
% vystupy: 
%   imSegmented - binarni obrazek stejne velikosti jako imOriginal, 1
%       oznacuje otisk a 0 znaci pozadi
%   imContour - kontura segmentace binarni obrazek obsahujici pouze
%   konturu, ne celou plochu segmentace

if nargin < 2
    tresh = 3;
end
if nargin < 3
    blkSize = 16;
end
if nargin < 4
    enh = true;
end
if nargin < 5
    smooth = 20;
end

im = imOriginal;

im = im/max(max(im));

if enh % enhance contrast
    im = histeq(im);
    im = medfilt2(im);
end


[fx fy] = gradient(im, 1);
grad = (abs(fx) + abs(fy))/2;
imSegmented = filter2(ones(blkSize), grad);
% hist(imSegmented(imSegmented>0), 50)
imSegmented = imSegmented > tresh;

%remove isolated blocks
bw = bwareaopen(imSegmented, 12*(blkSize^2), 4);
bw = imcomplement(bw);
bw = bwareaopen(bw, 12*(blkSize^2), 4);
bw = imcomplement(bw);

% smoothing
bw = padarray(bw, [blkSize blkSize], 'symmetric', 'both');
bw = medfilt2(bw, [smooth smooth]);
bw = bw(blkSize + 1 : size(bw,1) - blkSize, blkSize + 1 : size(bw,2) - blkSize);

imContour = bwperim(bw);
imContour = imresize(imContour, size(imOriginal));

imSegmented = bw;
imSegmented = imresize(imSegmented, size(imOriginal));